@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "La sol·licitud ha fallat, la connexió de xarxa no està disponible!",
     "Request unauthorized. Are you logged in?" : "Sol·licitud no autoritzada. Heu iniciat la sessió?",
-    "Request forbidden. Are you an admin?" : "Sol·licitud prohibida. Sou un administrador?",
     "Token expired or app not enabled! Reload the page!" : "El Token està caducat o l'aplicació no està activada! Torneu a carregar la pàgina!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Error intern servidor! Consulteu el fitxer data/nextcloud.log per obtenir informació addicional!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "La sol·licitud ha fallat, Nextcloud és actualment en mode de manteniment!",
@@ -15,17 +14,14 @@ OC.L10N.register(
     "Purge interval" : "Interval de purga",
     "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Nombre mí­nim de segons abans que les fonts i carpetes eliminades siguin eliminades definitivament de la base de dades; valors per sota de 60 segons seran ignorats.",
     "Maximum read count per feed" : "Màxim nombre de lectures per font",
-    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Defineix la quantitat màxima d'articles que es poden llegir per font que no s'esborraran en el treball de neteja; si reapareixen articles antics després d'haver estat llegits, augmenteu aquest valor; valors negatius, com -1, desactivaran aquesta caracterí­stica.",
     "Maximum redirects" : "Màxim de redirigits",
     "How many redirects the feed fetcher should follow." : "Quantes redireccions hauria de suportar el descarregador de fonts.",
     "Feed fetcher timeout" : "Temps d'espera exhaurit per a la descàrrega de la font",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Nombre màxim de segons per esperar que carregui una font de RSS o Atom; si pren més temps, l'actualització serà cancel·lada.",
     "Explore Service URL" : "Explora l'URL del Servei",
     "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "En cas d'haver-se emplenat, la URL d'aquest servei serà consultada per mostrar les fonts de la secció explorar fonts. Per tornar al servei d'exploració integrat, deixi aquest camp buit.",
-    "For more information check the wiki." : "Per obtenir més informació, consulteu la wiki.",
     "Update interval" : "Interval d'actualització",
     "Interval in seconds in which the feeds will be updated." : "Interval en segons en què s'actualitzaran les fonts de continguts.",
-    "Saved" : "S'ha desat",
     "Download" : "Baixa",
     "Close" : "Tanca",
     "Subscribe to" : "Subscriu a",
