@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "Το αίτημα απέτυχε, η σύνδεση στο δίκτυο δεν είναι διαθέσιμη!",
     "Request unauthorized. Are you logged in?" : "Το αίτημα δεν είναι εξουσιοδοτημένο. Είστε συνδεδεμένοι;",
-    "Request forbidden. Are you an admin?" : "Το αίτημα δεν επιτράπει. Είστε διαχειριστής;",
     "Token expired or app not enabled! Reload the page!" : "Η διαδικασία αναγνώρισης τερματίστηκε ή η εφαρμογή δεν είναι ενεργοποιημένη! Επαναφορτώστε τη σελίδα! ",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Εσωτερικό σφάλμα διακομιστή! Παρακαλώ ελέγξτε το αρχείο data/nextcloud.log για περισσότερες πληροφορίες!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Αποτυχία αιτήματος, το Nextcloud είναι προσωρινά σε κατάσταση συντήρησης!",
@@ -15,17 +14,14 @@ OC.L10N.register(
     "Purge interval" : "Διάστημα καθαρισμού",
     "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Η ελάχιστη διάρκεια σε δευτερόλεπτα μετά τη διαγραφή ροών και φακέλων, όπου θα αφαιρούνται από τη βάση δεδομένων; Οι τιμές κάτω των 60 δευτερολέπτων θα αγνοούνται.",
     "Maximum read count per feed" : "Ο μέγιστος αριθμός διαβασμένων ανά ροή",
-    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Ορίζει τη μέγιστη ποσότητα άρθρων που μπορούν να φορτωθούν ανά ροή, τα οποία δεν θα διαγραφούν από την υπηρεσία εκκαθάρισης; εάν τα παλαιά άρθρα επανεμφανιστούν μετά την ανάγνωσή τους, αυξήστε αυτήν την τιμή; οι αρνητικές τιμές, όπως το -1, θα απενεργοποιήσουν αυτή τη λειτουργία.",
     "Maximum redirects" : "Μέγιστος αριθμός ανακατευθύνσεων",
     "How many redirects the feed fetcher should follow." : "Πόσες ανακατευθύνσεις θα μπορεί να ακολουθεί η υπηρεσία ροών.",
     "Feed fetcher timeout" : "Χρόνος λήξης δέκτη ροής",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Μέγιστος χρόνος σε δευτερόλεπτα, αναμονής φόρτωσης μιας ροής RSS ή Atom; εάν χρειαστεί περισσότερο χρόνο η ενημέρωση θα ματαιωθεί.",
     "Explore Service URL" : "URL Υπηρεσίας Εξερεύνησης",
     "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Εάν οριστεί, θα τεθεί η ροή της διεύθυνση URL αυτής της υπηρεσίας στην ουρά, για προβολή στο τμήμα ροών. Για επιστροφή στην προεπιλογή αφήστε το πεδίο κενό.",
-    "For more information check the wiki." : "Για περισσότερες πληροφορίες δείτε στο wiki.",
     "Update interval" : "Εσωτερική ενημέρωση",
     "Interval in seconds in which the feeds will be updated." : "Διάστημα σε δευτερόλεπτα στο οποίο θα ενημερωθούν τα feeds.",
-    "Saved" : "Αποθηκεύτηκαν",
     "Download" : "Λήψη",
     "Close" : "Κλείσιμο",
     "Subscribe to" : "Εγγραφείτε στο",
