@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "Request failed, network connection unavailable!",
     "Request unauthorized. Are you logged in?" : "Request unauthorised. Are you logged in?",
-    "Request forbidden. Are you an admin?" : "Request forbidden. Are you an admin?",
     "Token expired or app not enabled! Reload the page!" : "Token expired or app not enabled! Reload the page!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Internal server error! Please check your data/nextcloud.log file for additional information!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Request failed, Nextcloud is in currently in maintenance mode!",
@@ -17,7 +16,6 @@ OC.L10N.register(
     "Maximum redirects" : "Maximum redirects",
     "Feed fetcher timeout" : "Feed fetcher timeout",
     "Explore Service URL" : "Explore Service URL",
-    "Saved" : "Saved",
     "Download" : "Download",
     "Close" : "Close",
     "No articles available" : "No articles available",
