@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "Pyyntö epäonnistui, yhteys ei ole käytettävissä!",
     "Request unauthorized. Are you logged in?" : "Pyyntö ei ole valtutettu. Oletko sisäänkirjautuneena?",
-    "Request forbidden. Are you an admin?" : "Pyyntö evätty. Oletko ylläpitäjä?",
     "Token expired or app not enabled! Reload the page!" : "Valtuutus vanheni tai sovellus ei ole käytössä! Lataa sivu uudelleen!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Sisäinen palvelinvirhe! Tarkista lisätiedot lokitiedostosta data/nextcloud.log!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Pyyntö epäonnistui, Nextcloud on parhaillaan ylläpitotilassa!",
@@ -24,11 +23,8 @@ OC.L10N.register(
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimiaika sekunteina, jonka aikana RSS- tai Atom-syöte odotetaan ladattavaksi. Jos lataus kestää pidempään, se perutaan.",
     "Explore Service URL" : "Syöte-ehdotusten palvelun URL",
     "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Palvelun osoite, josta haetaan ehdotuksia syötteistä Löydä uusia-osioon. Jätä tyhjäksi, jos haluat käyttää sisäänrakennettua oletuspalvelua.",
-    "For more information check the wiki." : "Lue lisätietoja wikistä.",
     "Update interval" : "Päivitysväli",
     "Interval in seconds in which the feeds will be updated." : "Syötteiden päivitysväli sekunteina.",
-    "For more information check the documentation." : "Lue lisätietoja dokumentaatiosta.",
-    "Saved" : "Tallennettu",
     "Download" : "Lataa",
     "Close" : "Sulje",
     "Subscribe to" : "Tilaa",
