@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "Zahtjev nije uspio, mrežna veza nije dostupna!",
     "Request unauthorized. Are you logged in?" : "Neovlašten zahtjev. Jeste li prijavljeni?",
-    "Request forbidden. Are you an admin?" : "Zahtjev je zabranjen. Jeste li administrator?",
     "Token expired or app not enabled! Reload the page!" : "Token je istekao ili aplikacija nije omogućena! Učitajte stranicu ponovo!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Unutarnja pogreška poslužitelja! Provjerite svoje podatke/datoteku nextcloud.log za dodatne informacije!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Zahtjev nije uspio, Nextcloud je trenutno u načinu održavanja!",
@@ -18,18 +17,14 @@ OC.L10N.register(
     "Purge interval" : "Interval čišćenja",
     "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Minimalna količina sekundi nakon uklanjanja izbrisanih feedova i mapa iz baze podataka; vrijednosti ispod 60 sekundi se zanemaruju.",
     "Maximum read count per feed" : "Maksimalni broj čitanja po sažetku",
-    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Određuje maksimalnu količinu članaka koji se mogu pročitati po sažetku koji neće biti izbrisani tijekom čišćenja; ako se stari članci ponovo pojave nakon što ih pročitate, povećajte vrijednost; negativne vrijednosti poput -1 isključit će ovu značajku.",
     "Maximum redirects" : "Maksimalni broj preusmjeravanja",
     "How many redirects the feed fetcher should follow." : "Koliko preusmjeravanja bi hvatač sažetaka trebao pratiti.",
     "Feed fetcher timeout" : "Vremensko ograničenje hvatača sažetaka",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimalni broj sekundi koliko se čeka učitavanje RSS i Atom sažetaka; ako učitavanje duže traje, nadogradnja se prekida.",
     "Explore Service URL" : "Istražite URL servisa",
     "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Ako postoji, URL servisa bit će analiziran za prikaz sažetaka u odjeljku za praćenje sažetaka. Kako biste ste vratili na „ugrađenu” vrijednost servisa za praćenje sažetaka, ostavite ovo polje za unos praznim.",
-    "For more information check the wiki." : "Za više informacija pogledajte wiki.",
     "Update interval" : "Interval ažuriranja",
     "Interval in seconds in which the feeds will be updated." : "Interval u sekundama u kojem će se sažeci ažurirati.",
-    "For more information check the documentation." : "Više informacija možete pronaći u dokumentaciji.",
-    "Saved" : "Spremljeno",
     "Download" : "Preuzmi",
     "Close" : "Zatvori",
     "Subscribe to" : "Pretplati se na",
