@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "Beiðni mistókst, engin nettenging tiltæk!",
     "Request unauthorized. Are you logged in?" : "Beiðni ekki heimiluð. Ertu skráð/ur inn?",
-    "Request forbidden. Are you an admin?" : "Beiðni bönnuð. Ertu kerfisstjóri?",
     "Token expired or app not enabled! Reload the page!" : "Kenniteikn er útrunnið eða forrit ekki virkt! Þú ættir að hlaða síðunni aftur inn!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Innri miðlaravilla! Athugaðu skrána data/nextcloud.log fyrir nánari upplýsingar!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Fyrirspurn brást, Nextcloud er núna í viðhaldsham.",
@@ -15,17 +14,14 @@ OC.L10N.register(
     "Purge interval" : "Millibil förgunar",
     "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Lágmarksfjöldi sekúndna þar til eydd streymi og möppur eru fjarlægð úr gagnagrunninum; gildi undir 60 sekúndum eru hunsuð.",
     "Maximum read count per feed" : "Hámarkfjöldi lestra á hvert streymi",
-    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Skilgeinir fjölda greina sem hægt er að lesa í hverju fréttastreymi og sem ekki verður eytt við hreinsunarverkefni: ef eldri greinar birtast aftur eftir að hafa verið lesnar, hækkaðu þá þetta gildi; neikvæð gildi eins og -1 slökkva alfarið á þessum eiginleika.",
     "Maximum redirects" : "Hámarks endurbeiningar",
     "How many redirects the feed fetcher should follow." : "Hversu mörgum endurbeiningum streymissugan á að fylgja.",
     "Feed fetcher timeout" : "Tímamörk streymissugu",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Hámarksfjöldi sekúndna sem beðið er eftir að RSS eða Atom-streymi hlaðist inn; ef það tekur lengri tíma er hætt við uppfærslu.",
     "Explore Service URL" : "Skoða slóð á þjónustu (URL)",
     "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Ef það er uppgefið, mun slóð þessarar þjónustu verða könnuð fyrir birtingu á streymum sem birtst í streymavafurshlutanum. Til að fara aftur í innbyggða vafurshlutann, skildu þá þetta eftir autt.",
-    "For more information check the wiki." : "Skoðaðu wiki-vefsvæðið til að fá frekari upplýsingar.",
     "Update interval" : "Uppfærslutíðni",
     "Interval in seconds in which the feeds will be updated." : "Tími í sekúndum sem líður milli þess sem streymi eru uppfærð.",
-    "Saved" : "Vistað",
     "Download" : "Niðurhal",
     "Close" : "Loka",
     "Subscribe to" : "Gerast áskrifandi að",
