@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "요청이 실패했습니다. 네트워크 연결을 사용할 수 없습니다.",
     "Request unauthorized. Are you logged in?" : "요청이 인증되지 않았습니다. 로그인되어 있습니까?",
-    "Request forbidden. Are you an admin?" : "요청이 금지되었습니다. 관리자 권한을 갖고 있습니까?",
     "Token expired or app not enabled! Reload the page!" : "토큰이 만료되었거나 앱이 활성화되어 있지 않습니다. 페이지를 새로 고치십시오!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "내부 서버 오류! 자세한 내용은 data/nextcloud.log 파일을 확인하십시오!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "요청이 실패했습니다. Nextcloud가 현재 관리 모드입니다!",
@@ -17,7 +16,6 @@ OC.L10N.register(
     "Maximum redirects" : "최대 넘겨주기 수",
     "Feed fetcher timeout" : "피드 가져오기 시간 제한",
     "Explore Service URL" : "탐색 서비스 URL",
-    "Saved" : "저장됨",
     "Download" : "다운로드",
     "Close" : "닫기",
     "No articles available" : "글 없음",
