@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "Fracàs de la requèsta, connexion ret indisponibla !",
     "Request unauthorized. Are you logged in?" : "Requèsta pas autorizada. Sètz plan connectat amb vòstres identificants ?",
-    "Request forbidden. Are you an admin?" : "Requèsta interdicha. Avètz los dreches admin ?",
     "Token expired or app not enabled! Reload the page!" : "Lo geton a expirat o l'aplicacion es pas activada ! Recargatz la pagina !",
     "Unread articles" : "Articles pas legits",
     "Purge interval" : "Interval de purga",
@@ -11,7 +10,6 @@ OC.L10N.register(
     "Maximum redirects" : "Nombre maximal de redireccions",
     "Feed fetcher timeout" : "Relambi d'espèra maximum del recuperador de flux",
     "Explore Service URL" : "URL del servici d'exploracion",
-    "Saved" : "Salvat",
     "Download" : "Telecargar",
     "Close" : "Tampar",
     "No articles available" : "Pas cap d'article disponible",
