@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "Kërkesa dështoi, s’funksionon lidhja në rrjet!",
     "Request unauthorized. Are you logged in?" : "Kërkesë e paautorizuar. Jeni i futur?",
-    "Request forbidden. Are you an admin?" : "Kërkesë e ndaluar. Jeni një përgjegjës?",
     "Token expired or app not enabled! Reload the page!" : "Token-i ka skaduar ose s’është aktivizuar aplikacioni! Ringarkoni faqen!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Gabim i brendshëm serveri! Ju lutemi kontrolloni skedarin tuaj data/nextcloud.log për informacion shtesë!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Kërkesa dështoi, Nextcloud është aktualisht më gjëndjen e mirëmbajtjes!",
@@ -16,7 +15,6 @@ OC.L10N.register(
     "Maximum redirects" : "Maksimum ridrejtimesh",
     "Feed fetcher timeout" : "Mbarim kohe për sjellësin e prurjeve",
     "Explore Service URL" : "URL Shërbimi Eksplorimesh",
-    "Saved" : "U ruajt",
     "Download" : "Shkarko",
     "Close" : "Mbylle",
     "No articles available" : "Jo artikuj të gatshëm",
