@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "Неуспео захтев. Мрежа није доступна!",
     "Request unauthorized. Are you logged in?" : "Неовлашћен захтев. Јесте ли пријављени?",
-    "Request forbidden. Are you an admin?" : "Забрањен захтев. Да ли сте администратор?",
     "Token expired or app not enabled! Reload the page!" : "Жетон је истекао или апликација није укључена! Учитајте поново страницу!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Интерна грешка на серверу! Проверите data/nextcloud.log фајл за додатне информације!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Неуспео захтев. Некстклауд сервер је тренутно у режиму приступа само једног корисника!",
@@ -15,17 +14,14 @@ OC.L10N.register(
     "Purge interval" : "Интервал чишћења",
     "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Минимални број секунди пошто се обрисани доводи и фасцикле уклоне из базе; вредности испод 60 секунди се игноришу.",
     "Maximum read count per feed" : "Максимални број читања по доводу",
-    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Дефинише максимални број чланака који се могу прочитати по доводу, а који неће бити избрисани када крене чишћење; ако се стари чланци поново појављују након што их прочитате, повећајте ову вредност; негативне вредности попут -1 искључују ову функцију у потпуности.",
     "Maximum redirects" : "Највише преусмеравања",
     "How many redirects the feed fetcher should follow." : "Колико ће се преусмеравања следити.",
     "Feed fetcher timeout" : "Рок добављања довода",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Време у секундама које ће се чекати да се довод учита. Ако траје дуже, ажурирање ће се прекинути.",
     "Explore Service URL" : "Истражите сервисну адресу",
     "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Ако је дато, ова сервисна адреса ће бити упитана за приказивање у секцији за истраживање довода. За повратак на коришћење уграђеног сервиса за истраживање, оставите ово празно.",
-    "For more information check the wiki." : "За више информација, погледајте вики.",
     "Update interval" : "Време ажурирања",
     "Interval in seconds in which the feeds will be updated." : "Интервал у секундама у којем се ће доводи да се ажурирају.",
-    "Saved" : "Сачувано",
     "Download" : "Преузми",
     "Close" : "Затвори",
     "Subscribe to" : "Претплати се на",
