@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "Förfrågan misslyckades, nätverksanslutning otillgänglig!",
     "Request unauthorized. Are you logged in?" : "Ogiltig begäran. Är du inloggad?",
-    "Request forbidden. Are you an admin?" : "Förfrågan förbjuden. Är du administratör?",
     "Token expired or app not enabled! Reload the page!" : "Polletten föråldrad eller så är applikationen inte aktiverad! Uppdatera sidan.",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Internt serverfel! Vänligen kontrollera din loggfil under data/nextcloud.log för mer information!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Förfrågan misslyckades. Nextcloud är för närvarande i underhållsläge!",
@@ -20,11 +19,8 @@ OC.L10N.register(
     "Maximum redirects" : "Maximala omdirigeringar",
     "Feed fetcher timeout" : "Timeout för flödes-hämtare",
     "Explore Service URL" : "Utforska tjänstwebbadress",
-    "For more information check the wiki." : "Se wikin för mer information.",
     "Update interval" : "Uppdateringsintervall",
     "Interval in seconds in which the feeds will be updated." : "Antal sekunder mellan uppdateringar av flödena.",
-    "For more information check the documentation." : "Se dokumentationen för mer information.",
-    "Saved" : "Sparad",
     "Download" : "Hämta",
     "Close" : "Stäng",
     "Subscribe to" : "Prenumerera på",
