@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "คำขอล้มเหลวเชื่อมต่อเครือข่ายไม่ได้!",
     "Request unauthorized. Are you logged in?" : "คำขอไม่ได้รับอนุญาต คุณเข้าสู่ระบบ?",
-    "Request forbidden. Are you an admin?" : "คำขอถูกปฏิเสธ คุณเป็นผู้ดูแลระบบ?",
     "Token expired or app not enabled! Reload the page!" : "โทเค็นหมดอายุหรือไม่เปิดใช้งานแอพพลิเคชัน! โหลดหน้าใหม่อีกครั้ง!",
     "Unread articles" : "บทความที่ยังไม่ได้อ่าน",
     "Purge interval" : "ช่วงเวลาที่ล้าง",
@@ -11,7 +10,6 @@ OC.L10N.register(
     "Maximum redirects" : "เปลี่ยนเส้นทางสูงสุด",
     "Feed fetcher timeout" : "ตัวเรียกฟีดหมดเวลา",
     "Explore Service URL" : "สำรวจบริการ URL",
-    "Saved" : "บันทึกแล้ว",
     "Download" : "ดาวน์โหลด",
     "Close" : "ปิด",
     "No articles available" : "ไม่มีบทความที่",
