@@ -3,15 +3,19 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "Запит не вдався, немає мережевого з'єднання!",
     "Request unauthorized. Are you logged in?" : "Запит не авторизований. Ви увійшли в систему?",
-    "Request forbidden. Are you an admin?" : "Запит заборонений. Ви справді адміністратор?",
+    "Request forbidden. Are you an administrator?" : "Запит заборонено. Ви адміністратор?",
     "Token expired or app not enabled! Reload the page!" : "Термін дії токена закінчився або програма не задіяна! Перезагрузіть сторінку!",
+    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Внутрішня помилка сервера! Щоб отримати додаткову інформацію, перевірте файл data/nextcloud.log!",
+    "Request failed, Nextcloud is in currently in maintenance mode!" : "Помилка запиту, Nextcloud зараз у режимі обслуговування!",
     "Unread articles" : "Непрочитані статті",
+    "Use system cron for updates" : "Використовуйте системний cron для оновлень",
     "Purge interval" : "Очистити оновлення",
     "Maximum read count per feed" : "Максимальна кількість статей для стрічки",
+    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Визначає максимальну кількість статей, які можна прочитати на канал, які не будуть видалені під час завдання очищення; якщо старі статті знову з’являються після прочитання, збільште це значення; від'ємні значення, такі як -1, вимкнуть цю функцію.",
     "Maximum redirects" : "Максимум перенаправлень",
     "Feed fetcher timeout" : "Час очікування для завантажувача стрічки",
     "Explore Service URL" : "URL сервісу дослідження",
-    "Saved" : "Збереженно",
+    "Successfully updated news configuration" : "Конфігурацію новин успішно оновлено",
     "Download" : "Завантажити",
     "Close" : "Закрити",
     "No articles available" : "Немає доступних статей",
@@ -47,6 +51,7 @@ OC.L10N.register(
     "Scroll to active navigation entry" : "Перехід до обраного елементу",
     "Mark current article's feed/folder read" : "Зробити поточну подачу/теку артиклю лише для читання",
     "How to set up the operating system cron" : "Як налаштувати cron операційної системи",
+    "Install and set up a faster parallel updater that uses the News app's update API" : "Установіть і налаштуйте швидший паралельний засіб оновлення, який використовує API оновлення програми Новини",
     "Subscribe" : "Підписатися",
     "Web address" : "Веб адреса",
     "Feed exists already!" : "Стрічка вже існує !",
@@ -57,10 +62,12 @@ OC.L10N.register(
     "Go back" : "Повернутися назад",
     "Folder exists already!" : "Тека вже існує !",
     "Credentials" : "Облікові дані",
+    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Облікові дані HTTP Basic Auth повинні зберігатися незашифрованими! Усі, хто має доступ до сервера або бази даних, зможуть отримати до них доступ!",
     "Password" : "Пароль",
     "New Folder" : "Нова тека",
     "Create" : "Створити",
     "Explore" : "Дослідити",
+    "Update failed more than 50 times" : "Помилка оновлення понад 50 разів",
     "Deleted feed" : "Вилучена стрічка",
     "Undo delete feed" : "Скасувати вилучення стрічки",
     "Rename" : "Перейменувати",
@@ -84,6 +91,7 @@ OC.L10N.register(
     "Subscriptions (OPML)" : "Підписки (OPML)",
     "Import" : "Імпорт",
     "Export" : "Експорт",
+    "Error when importing: OPML is does neither contain feeds nor folders" : "Помилка під час імпорту: OPML не містить ані каналів, ані папок",
     "Unread/Starred Articles" : "Непрочитані/Вибрані статті",
     "Error when importing: file does not contain valid JSON" : "Помилка при імпорті: файл не містить дійсний JSON",
     "Help" : "Допомога",
