@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "请求失败，网络连接不可用！",
     "Request unauthorized. Are you logged in?" : "请求未通过认证。您登录成功了吗？",
-    "Request forbidden. Are you an admin?" : "请求被拒绝。您是系统管理员吗？",
     "Token expired or app not enabled! Reload the page!" : "令牌过期或者应用没有启用！重新加载页面！",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "内部服务器错误！请检查您的 data/nextcloud.log 文件获取更多详细信息！",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "请求失败，Nextcloud 现处于维护模式！",
@@ -18,18 +17,14 @@ OC.L10N.register(
     "Purge interval" : "清理间隔",
     "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "从数据库中移除的订阅源和文件夹后的最小秒数；低于 60 秒的值将被忽略。",
     "Maximum read count per feed" : "每个订阅源的最大读取次数",
-    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "定义每个订阅源可以读取的最大文章数，定时清理不会删除这些文章；如果在阅读后重新出现旧文章，请增加此值；负值（例如-1）将关闭此功能。",
     "Maximum redirects" : "最大重定向次数",
     "How many redirects the feed fetcher should follow." : "订阅源获取器最多应跟随多少次重定向。",
     "Feed fetcher timeout" : "订阅源获取器超时",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "最长的等待 RSS 或 Atom 订阅源加载的秒数；如果比这个时间更长更新将会中止。",
     "Explore Service URL" : "资源管理服务URL",
     "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "如果给出，则会在查询订阅源部分中查询此服务的 URL 以显示订阅源。要回到内置的探索服务，请将此输入留空。",
-    "For more information check the wiki." : "访问 Wiki 了解更多信息。",
     "Update interval" : "更新间隔",
     "Interval in seconds in which the feeds will be updated." : "订阅源更新的时间间隔（以秒为单位）。",
-    "For more information check the documentation." : "更多信息请见文档",
-    "Saved" : "已保存",
     "Download" : "下载",
     "Close" : "关闭",
     "Subscribe to" : "订阅",
